==> dojo_1.15.4+dfsg1.orig.tar.xz: dojo-release-1.15.4-src/dojo/cldr/nls/nb/persian.js <==
define(
//begin v1.x content
{
	"field-quarter-short-relative+0": "dette kv.",
	"field-quarter-short-relative+1": "neste kv.",
	"field-tue-relative+-1": "tirsdag sist uke",
	"field-year": "år",
	"field-wed-relative+0": "onsdag denne uken",
	"field-wed-relative+1": "onsdag neste uke",
	"timeFormat-short": "HH.mm",
	"field-minute": "minutt",
	"field-month-narrow-relative+-1": "forrige md.",
	"field-tue-narrow-relative+0": "denne ti.",
	"field-tue-narrow-relative+1": "neste ti.",
	"field-thu-short-relative+0": "denne tor.",
	"field-day-short-relative+-1": "i går",
	"field-thu-short-relative+1": "neste tor.",
	"field-day-relative+0": "i dag",
	"field-day-short-relative+-2": "i forgårs",
	"field-day-relative+1": "i morgen",
	"field-week-narrow-relative+0": "denne uken",
	"field-day-relative+2": "i overmorgen",
	"field-week-narrow-relative+1": "neste uke",
	"field-wed-narrow-relative+-1": "sist on.",
	"field-year-narrow": "år",
	"field-tue-relative+0": "tirsdag denne uken",
	"field-tue-relative+1": "tirsdag neste uke",
	"field-second-short": "sek",
	"dayPeriods-format-narrow-am": "a",
	"dateFormatItem-MMMd": "d. MMM",
	"dayPeriods-format-abbr-am": "a.m.",
	"field-week-relative+0": "denne uken",
	"field-month-relative+0": "denne måneden",
	"field-week-relative+1": "neste uke",
	"field-month-relative+1": "neste måned",
	"field-sun-narrow-relative+0": "denne sø.",
	"timeFormat-medium": "HH.mm.ss",
	"field-mon-short-relative+0": "denne man.",
	"field-sun-narrow-relative+1": "neste sø.",
	"field-mon-short-relative+1": "neste man.",
	"field-second-relative+0": "nå",
	"dateFormatItem-yyyyQQQ": "QQQ y G",
	"months-standAlone-narrow": [
		"1",
		"2",
		"3",
		"4",
		"5",
		"6",
		"7",
		"8",
		"9",
		"10",
		"11",
		"12"
	],
	"eraNames": [
		"AP"
	],
	"dayPeriods-standAlone-abbr-pm": "p.m.",
	"field-month-short": "mnd.",
	"dateFormatItem-GyMMMEd": "E d. MMM y G",
	"dateFormatItem-yyyyMd": "d.M.y G",
	"field-day": "dag",
	"field-year-relative+-1": "i fjor",
	"dayPeriods-format-wide-am": "a.m.",
	"field-sat-short-relative+-1": "sist lør.",
	"field-hour-relative+0": "denne timen",
	"dateFormatItem-yyyyMEd": "E d.M.y G",
	"field-wed-relative+-1": "onsdag sist uke",
	"field-sat-narrow-relative+-1": "sist lø.",
	"field-second": "sekund",
	"days-standAlone-narrow": [
		"S",
		"M",
		"T",
		"O",
		"T",
		"F",
		"L"
	],
	"dayPeriods-standAlone-wide-pm": "p.m.",
	"dateFormat-long": "d. MMMM y G",
	"dateFormatItem-GyMMMd": "d. MMM y G",
	"field-quarter": "kvartal",
	"field-week-short": "uke",
	"quarters-standAlone-wide": [
		"1. kvartal",
		"2. kvartal",
		"3. kvartal",
		"4. kvartal"
	],
	"days-format-narrow": [
		"S",
		"M",
		"T",
		"O",
		"T",
		"F",
		"L"
	],
	"field-tue-short-relative+0": "denne tir.",
	"field-tue-short-relative+1": "neste tir.",
	"field-month-short-relative+-1": "forrige md.",
	"field-mon-relative+-1": "mandag sist uke",
	"dateFormatItem-GyMMM": "MMM y G",
	"field-month": "måned",
	"field-day-narrow": "d.",
	"field-minute-short": "min",
	"field-dayperiod": "a.m./p.m.",
	"field-sat-short-relative+0": "denne lør.",
	"field-sat-short-relative+1": "neste lør.",
	"dayPeriods-format-narrow-pm": "p",
	"dateFormat-medium": "d. MMM y G",
	"dateFormatItem-yyyyMMMM": "MMMM y G",
	"eraAbbr": [
		"AP"
	],
	"quarters-standAlone-abbr": [
		"K1",
		"K2",
		"K3",
		"K4"
	],
	"dayPeriods-format-abbr-pm": "p.m.",
	"dateFormatItem-yyyyM": "M.y G",
	"field-second-narrow": "s",
	"field-mon-relative+0": "mandag denne uken",
	"field-mon-relative+1": "mandag neste uke",
	"field-year-short": "år",
	"months-format-narrow": [
		"1",
		"2",
		"3",
		"4",
		"5",
		"6",
		"7",
		"8",
		"9",
		"10",
		"11",
		"12"
	],
	"field-quarter-relative+-1": "forrige kvartal",
	"dateFormatItem-yyyyMMMd": "d. MMM y G",
	"dayPeriods-standAlone-narrow-am": "a.m.",
	"field-week-narrow-relative+-1": "forrige uke",
	"days-format-short": [
		"sø.",
		"ma.",
		"ti.",
		"on.",
		"to.",
		"fr.",
		"lø."
	],
	"quarters-format-narrow": [
		"1.",
		"2.",
		"3.",
		"4."
	],
	"dayPeriods-format-wide-pm": "p.m.",
	"field-sat-relative+-1": "lørdag sist uke",
	"dateFormatItem-Md": "d.M.",
	"field-hour": "time",
	"months-format-wide": [
		"farvardin",
		"ordibehesht",
		"khordad",
		"tir",
		"mordad",
		"shahrivar",
		"mehr",
		"aban",
		"azar",
		"dey",
		"bahman",
		"esfand"
	],
	"dateFormat-full": "EEEE d. MMMM y G",
	"field-month-relative+-1": "forrige måned",
	"field-quarter-short": "kv.",
	"field-sat-narrow-relative+0": "denne lø.",
	"field-fri-relative+0": "fredag denne uken",
	"field-sat-narrow-relative+1": "neste lø.",
	"field-fri-relative+1": "fredag neste uke",
	"field-month-narrow-relative+0": "denne md.",
	"field-month-narrow-relative+1": "neste md.",
	"field-sun-short-relative+0": "denne søn.",
	"field-sun-short-relative+1": "neste søn.",
	"field-week-relative+-1": "forrige uke",
	"field-quarter-short-relative+-1": "forrige kv.",
	"months-format-abbr": [
		"farvardin",
		"ordibehesht",
		"khordad",
		"tir",
		"mordad",
		"shahrivar",
		"mehr",
		"aban",
		"azar",
		"dey",
		"bahman",
		"esfand"
	],
	"field-quarter-relative+0": "dette kvartalet",
	"field-minute-relative+0": "dette minuttet",
	"timeFormat-long": "HH.mm.ss z",
	"field-quarter-relative+1": "neste kvartal",
	"field-wed-short-relative+-1": "sist ons.",
	"dateFormat-short": "d.M.y G",
	"field-thu-short-relative+-1": "sist tor.",
	"days-standAlone-wide": [
		"søndag",
		"mandag",
		"tirsdag",
		"onsdag",
		"torsdag",
		"fredag",
		"lørdag"
	],
	"dateFormatItem-yyyyMMMEd": "E d. MMM y G",
	"field-mon-narrow-relative+-1": "sist ma.",
	"dateFormatItem-MMMMd": "d. MMMM",
	"field-thu-narrow-relative+-1": "sist to.",
	"dateFormatItem-E": "ccc",
	"field-tue-narrow-relative+-1": "sist ti.",
	"dateFormatItem-yyyy": "y G",
	"dayPeriods-standAlone-narrow-pm": "p.m.",
	"field-wed-short-relative+0": "denne ons.",
	"dateFormatItem-M": "L.",
	"months-standAlone-wide": [
		"farvardin",
		"ordibehesht",
		"khordad",
		"tir",
		"mordad",
		"shahrivar",
		"mehr",
		"aban",
		"azar",
		"dey",
		"bahman",
		"esfand"
	],
	"field-wed-short-relative+1": "neste ons.",
	"field-sun-relative+-1": "søndag sist uke",
	"days-standAlone-abbr": [
		"søn.",
		"man.",
		"tir.",
		"ons.",
		"tor.",
		"fre.",
		"lør."
	],
	"dateFormatItem-d": "d.",
	"field-weekday": "ukedag",
	"field-day-short-relative+0": "i dag",
	"field-quarter-narrow-relative+0": "dette kv.",
	"field-sat-relative+0": "lørdag denne uken",
	"field-day-short-relative+1": "i morgen",
	"field-quarter-narrow-relative+1": "neste kv.",
	"field-sat-relative+1": "lørdag neste uke",
	"field-day-short-relative+2": "i overmorgen",
	"field-week-short-relative+0": "denne uken",
	"field-week-short-relative+1": "neste uke",
	"months-standAlone-abbr": [
		"farvardin",
		"ordibehesht",
		"khordad",
		"tir",
		"mordad",
		"shahrivar",
		"mehr",
		"aban",
		"azar",
		"dey",
		"bahman",
		"esfand"
	],
	"field-month-short-relative+0": "denne md.",
	"field-month-short-relative+1": "neste md.",
	"timeFormat-full": "HH.mm.ss zzzz",
	"dateFormatItem-MEd": "E d.M",
	"dateFormatItem-y": "y G",
	"field-thu-narrow-relative+0": "denne to.",
	"field-thu-narrow-relative+1": "neste to.",
	"field-sun-narrow-relative+-1": "sist sø.",
	"field-mon-short-relative+-1": "sist man.",
	"field-thu-relative+0": "torsdag denne uken",
	"field-thu-relative+1": "torsdag neste uke",
	"field-fri-short-relative+-1": "sist fre.",
	"field-thu-relative+-1": "torsdag sist uke",
	"field-week": "uke",
	"quarters-standAlone-narrow": [
		"1.",
		"2.",
		"3.",
		"4."
	],
	"quarters-format-wide": [
		"1. kvartal",
		"2. kvartal",
		"3. kvartal",
		"4. kvartal"
	],
	"dateFormatItem-Ed": "E d.",
	"field-wed-narrow-relative+0": "denne on.",
	"field-wed-narrow-relative+1": "neste on.",
	"field-quarter-narrow-relative+-1": "forrige kv.",
	"dateFormatItem-yyyyMMM": "MMM y G",
	"field-fri-short-relative+0": "denne fre.",
	"field-fri-short-relative+1": "neste fre.",
	"days-standAlone-short": [
		"sø.",
		"ma.",
		"ti.",
		"on.",
		"to.",
		"fr.",
		"lø."
	],
	"field-week-short-relative+-1": "forrige uke",
	"dateFormatItem-yyyyQQQQ": "QQQQ y G",
	"field-hour-short": "t",
	"quarters-format-abbr": [
		"K1",
		"K2",
		"K3",
		"K4"
	],
	"field-month-narrow": "md.",
	"field-hour-narrow": "t",
	"field-fri-narrow-relative+-1": "sist fr.",
	"field-year-relative+0": "i år",
	"field-year-relative+1": "neste år",
	"field-fri-relative+-1": "fredag sist uke",
	"eraNarrow": "AP",
	"field-tue-short-relative+-1": "sist tir.",
	"field-minute-narrow": "m",
	"days-format-wide": [
		"søndag",
		"mandag",
		"tirsdag",
		"onsdag",
		"torsdag",
		"fredag",
		"lørdag"
	],
	"field-mon-narrow-relative+0": "denne ma.",
	"field-mon-narrow-relative+1": "neste ma.",
	"field-zone": "tidssone",
	"dateFormatItem-MMMEd": "E d. MMM",
	"field-quarter-narrow": "kv.",
	"field-sun-short-relative+-1": "sist søn.",
	"field-day-relative+-1": "i går",
	"dayPeriods-standAlone-abbr-am": "a.m.",
	"field-day-relative+-2": "i forgårs",
	"days-format-abbr": [
		"søn.",
		"man.",
		"tir.",
		"ons.",
		"tor.",
		"fre.",
		"lør."
	],
	"field-sun-relative+0": "søndag denne uken",
	"field-sun-relative+1": "søndag neste uke",
	"dateFormatItem-Gy": "y G",
	"field-day-short": "dag",
	"field-week-narrow": "u.",
	"field-era": "tidsalder",
	"field-fri-narrow-relative+0": "denne fr.",
	"field-fri-narrow-relative+1": "neste fr.",
	"dayPeriods-standAlone-wide-am": "a.m."
}
//end v1.x content
);

==> dojo_1.17.2+dfsg1.orig.tar.xz: dojo-release-1.17.2-src/dojo/cldr/nls/nb/persian.js <==
define(
//begin v1.x content
{
	"field-quarter-short-relative+0": "dette kv.",
	"field-quarter-short-relative+1": "neste kv.",
	"field-tue-relative+-1": "forrige tirsdag",
	"field-year": "år",
	"field-wed-relative+0": "onsdag",
	"field-wed-relative+1": "neste onsdag",
	"timeFormat-short": "HH.mm",
	"field-minute": "minutt",
	"field-month-narrow-relative+-1": "forrige md.",
	"field-tue-narrow-relative+0": "denne ti.",
	"field-tue-narrow-relative+1": "neste ti.",
	"field-thu-short-relative+0": "denne tor.",
	"field-day-short-relative+-1": "i går",
	"dateTimeFormat-short": "{1} {0}",
	"field-thu-short-relative+1": "neste tor.",
	"field-day-relative+0": "i dag",
	"field-day-short-relative+-2": "i forgårs",
	"field-day-relative+1": "i morgen",
	"field-week-narrow-relative+0": "denne uken",
	"field-day-relative+2": "i overmorgen",
	"field-week-narrow-relative+1": "neste uke",
	"field-wed-narrow-relative+-1": "sist on.",
	"field-year-narrow": "år",
	"field-era-short": "tidsalder",
	"field-year-narrow-relative+0": "i år",
	"field-tue-relative+0": "tirsdag",
	"field-year-narrow-relative+1": "neste år",
	"field-tue-relative+1": "neste tirsdag",
	"field-weekdayOfMonth": "ukedag i måneden",
	"field-second-short": "sek",
	"dayPeriods-format-narrow-am": "a",
	"dateFormatItem-yyyyMM": "MM.y G",
	"dateFormatItem-MMMd": "d. MMM",
	"field-weekdayOfMonth-narrow": "uked. i md.",
	"dayPeriods-format-abbr-am": "a.m.",
	"field-week-relative+0": "denne uken",
	"field-month-relative+0": "denne måneden",
	"field-week-relative+1": "neste uke",
	"field-month-relative+1": "neste måned",
	"field-sun-narrow-relative+0": "denne sø.",
	"timeFormat-medium": "HH.mm.ss",
	"field-mon-short-relative+0": "denne man.",
	"field-sun-narrow-relative+1": "neste sø.",
	"field-mon-short-relative+1": "neste man.",
	"field-second-relative+0": "nå",
	"dateFormatItem-yyyyQQQ": "QQQ y G",
	"months-standAlone-narrow": [
		"1",
		"2",
		"3",
		"4",
		"5",
		"6",
		"7",
		"8",
		"9",
		"10",
		"11",
		"12"
	],
	"eraNames": [
		"AP"
	],
	"field-weekOfMonth": "uke i måneden",
	"dayPeriods-standAlone-abbr-pm": "p.m.",
	"field-month-short": "mnd.",
	"dateFormatItem-GyMMMEd": "E d. MMM y G",
	"dateFormatItem-yyyyMd": "d.M.y G",
	"field-day": "dag",
	"field-dayOfYear-short": "dag i året",
	"field-year-relative+-1": "i fjor",
	"dayPeriods-format-wide-am": "a.m.",
	"field-sat-short-relative+-1": "sist lør.",
	"field-hour-relative+0": "denne timen",
	"dateFormatItem-yyyyMEd": "E d.M.y G",
	"field-second-short-relative+0": "nå",
	"field-wed-relative+-1": "forrige onsdag",
	"dateTimeFormat-medium": "{1} {0}",
	"field-sat-narrow-relative+-1": "sist lø.",
	"field-second": "sekund",
	"days-standAlone-narrow": [
		"S",
		"M",
		"T",
		"O",
		"T",
		"F",
		"L"
	],
	"dayPeriods-standAlone-wide-pm": "p.m.",
	"dateFormat-long": "d. MMMM y G",
	"dateFormatItem-GyMMMd": "d. MMM y G",
	"field-quarter": "kvartal",
	"field-week-short": "uke",
	"field-day-narrow-relative+0": "i dag",
	"field-day-narrow-relative+1": "i morgen",
	"field-day-narrow-relative+2": "+2 d.",
	"quarters-standAlone-wide": [
		"1. kvartal",
		"2. kvartal",
		"3. kvartal",
		"4. kvartal"
	],
	"days-format-narrow": [
		"S",
		"M",
		"T",
		"O",
		"T",
		"F",
		"L"
	],
	"field-tue-short-relative+0": "denne tir.",
	"field-tue-short-relative+1": "neste tir.",
	"field-month-short-relative+-1": "forrige md.",
	"field-mon-relative+-1": "forrige mandag",
	"dateFormatItem-GyMMM": "MMM y G",
	"field-month": "måned",
	"field-day-narrow": "d.",
	"dateFormatItem-MMM": "LLL",
	"field-minute-short": "min",
	"field-dayperiod": "a.m./p.m.",
	"field-sat-short-relative+0": "denne lør.",
	"field-sat-short-relative+1": "neste lør.",
	"dayPeriods-format-narrow-pm": "p",
	"dateFormat-medium": "d. MMM y G",
	"dateFormatItem-yyyyMMMM": "MMMM y G",
	"eraAbbr": [
		"AP"
	],
	"quarters-standAlone-abbr": [
		"K1",
		"K2",
		"K3",
		"K4"
	],
	"dayPeriods-format-abbr-pm": "p.m.",
	"dateFormatItem-yyyyM": "M.y G",
	"field-second-narrow": "s",
	"field-mon-relative+0": "mandag",
	"field-mon-relative+1": "neste mandag",
	"field-day-narrow-relative+-1": "i går",
	"field-year-short": "år",
	"field-day-narrow-relative+-2": "-2 d.",
	"months-format-narrow": [
		"1",
		"2",
		"3",
		"4",
		"5",
		"6",
		"7",
		"8",
		"9",
		"10",
		"11",
		"12"
	],
	"field-quarter-relative+-1": "forrige kvartal",
	"dateFormatItem-yyyyMMMd": "d. MMM y G",
	"field-dayperiod-narrow": "am/pm",
	"dayPeriods-standAlone-narrow-am": "a.m.",
	"field-week-narrow-relative+-1": "forrige uke",
	"days-format-short": [
		"sø.",
		"ma.",
		"ti.",
		"on.",
		"to.",
		"fr.",
		"lø."
	],
	"quarters-format-narrow": [
		"1.",
		"2.",
		"3.",
		"4."
	],
	"dayPeriods-format-wide-pm": "p.m.",
	"field-dayOfYear": "dag i året",
	"field-sat-relative+-1": "forrige lørdag",
	"dateTimeFormat-long": "{1} {0}",
	"dateFormatItem-Md": "d.M.",
	"field-hour": "time",
	"months-format-wide": [
		"farvardin",
		"ordibehesht",
		"khordad",
		"tir",
		"mordad",
		"shahrivar",
		"mehr",
		"aban",
		"azar",
		"dey",
		"bahman",
		"esfand"
	],
	"dateFormat-full": "EEEE d. MMMM y G",
	"field-month-relative+-1": "forrige måned",
	"field-quarter-short": "kv.",
	"field-sat-narrow-relative+0": "denne lø.",
	"field-fri-relative+0": "fredag",
	"field-sat-narrow-relative+1": "neste lø.",
	"field-fri-relative+1": "neste fredag",
	"field-month-narrow-relative+0": "denne md.",
	"field-month-narrow-relative+1": "neste md.",
	"field-sun-short-relative+0": "denne søn.",
	"field-sun-short-relative+1": "neste søn.",
	"field-week-relative+-1": "forrige uke",
	"field-quarter-short-relative+-1": "forrige kv.",
	"months-format-abbr": [
		"farvardin",
		"ordibehesht",
		"khordad",
		"tir",
		"mordad",
		"shahrivar",
		"mehr",
		"aban",
		"azar",
		"dey",
		"bahman",
		"esfand"
	],
	"field-quarter-relative+0": "dette kvartalet",
	"field-minute-relative+0": "dette minuttet",
	"timeFormat-long": "HH.mm.ss z",
	"field-quarter-relative+1": "neste kvartal",
	"field-wed-short-relative+-1": "sist ons.",
	"dateFormat-short": "d.M.y G",
	"field-thu-short-relative+-1": "sist tor.",
	"field-year-narrow-relative+-1": "i fjor",
	"days-standAlone-wide": [
		"søndag",
		"mandag",
		"tirsdag",
		"onsdag",
		"torsdag",
		"fredag",
		"lørdag"
	],
	"dateFormatItem-yyyyMMMEd": "E d. MMM y G",
	"field-mon-narrow-relative+-1": "sist ma.",
	"dateFormatItem-MMMMd": "d. MMMM",
	"field-thu-narrow-relative+-1": "sist to.",
	"dateFormatItem-E": "ccc",
	"field-weekOfMonth-short": "uke i mnd.",
	"field-tue-narrow-relative+-1": "sist ti.",
	"dateFormatItem-yyyy": "y G",
	"dayPeriods-standAlone-narrow-pm": "p.m.",
	"dateFormatItem-M": "L.",
	"months-standAlone-wide": [
		"farvardin",
		"ordibehesht",
		"khordad",
		"tir",
		"mordad",
		"shahrivar",
		"mehr",
		"aban",
		"azar",
		"dey",
		"bahman",
		"esfand"
	],
	"field-wed-short-relative+0": "denne ons.",
	"field-wed-short-relative+1": "neste ons.",
	"field-sun-relative+-1": "forrige søndag",
	"days-standAlone-abbr": [
		"søn.",
		"man.",
		"tir.",
		"ons.",
		"tor.",
		"fre.",
		"lør."
	],
	"dateTimeFormat-full": "{1} {0}",
	"field-second-narrow-relative+0": "nå",
	"dateFormatItem-d": "d.",
	"field-weekday": "ukedag",
	"field-day-short-relative+0": "i dag",
	"field-quarter-narrow-relative+0": "dette kv.",
	"field-day-short-relative+1": "i morgen",
	"field-sat-relative+0": "lørdag",
	"field-quarter-narrow-relative+1": "neste kv.",
	"field-day-short-relative+2": "i overmorgen",
	"field-sat-relative+1": "neste lørdag",
	"field-week-short-relative+0": "denne uken",
	"field-week-short-relative+1": "neste uke",
	"months-standAlone-abbr": [
		"farvardin",
		"ordibehesht",
		"khordad",
		"tir",
		"mordad",
		"shahrivar",
		"mehr",
		"aban",
		"azar",
		"dey",
		"bahman",
		"esfand"
	],
	"field-dayOfYear-narrow": "d. i året",
	"field-month-short-relative+0": "denne md.",
	"field-month-short-relative+1": "neste md.",
	"field-weekdayOfMonth-short": "uked. i mnd.",
	"timeFormat-full": "HH.mm.ss zzzz",
	"dateFormatItem-MEd": "E d.M",
	"field-zone-narrow": "tidssone",
	"dateFormatItem-y": "y G",
	"field-thu-narrow-relative+0": "denne to.",
	"field-sun-narrow-relative+-1": "sist sø.",
	"field-mon-short-relative+-1": "sist man.",
	"field-thu-narrow-relative+1": "neste to.",
	"field-thu-relative+0": "torsdag",
	"field-thu-relative+1": "neste torsdag",
	"field-fri-short-relative+-1": "sist fre.",
	"field-thu-relative+-1": "forrige torsdag",
	"field-week": "uke",
	"quarters-standAlone-narrow": [
		"1.",
		"2.",
		"3.",
		"4."
	],
	"quarters-format-wide": [
		"1. kvartal",
		"2. kvartal",
		"3. kvartal",
		"4. kvartal"
	],
	"dateFormatItem-Ed": "E d.",
	"field-wed-narrow-relative+0": "denne on.",
	"field-wed-narrow-relative+1": "neste on.",
	"field-quarter-narrow-relative+-1": "forrige kv.",
	"field-year-short-relative+0": "i år",
	"dateFormatItem-yyyyMMM": "MMM y G",
	"field-dayperiod-short": "am/pm",
	"field-year-short-relative+1": "neste år",
	"field-fri-short-relative+0": "denne fre.",
	"field-fri-short-relative+1": "neste fre.",
	"days-standAlone-short": [
		"sø.",
		"ma.",
		"ti.",
		"on.",
		"to.",
		"fr.",
		"lø."
	],
	"field-week-short-relative+-1": "forrige uke",
	"dateFormatItem-yyyyQQQQ": "QQQQ y G",
	"field-hour-short": "t",
	"field-zone-short": "tidssone",
	"quarters-format-abbr": [
		"K1",
		"K2",
		"K3",
		"K4"
	],
	"field-month-narrow": "md.",
	"field-hour-narrow": "t",
	"field-fri-narrow-relative+-1": "sist fr.",
	"field-year-relative+0": "i år",
	"field-year-relative+1": "neste år",
	"field-era-narrow": "tidsalder",
	"field-fri-relative+-1": "forrige fredag",
	"eraNarrow": "AP",
	"field-tue-short-relative+-1": "sist tir.",
	"field-minute-narrow": "m",
	"days-format-wide": [
		"søndag",
		"mandag",
		"tirsdag",
		"onsdag",
		"torsdag",
		"fredag",
		"lørdag"
	],
	"field-mon-narrow-relative+0": "denne ma.",
	"field-mon-narrow-relative+1": "neste ma.",
	"field-year-short-relative+-1": "i fjor",
	"field-zone": "tidssone",
	"dateFormatItem-MMMEd": "E d. MMM",
	"field-weekOfMonth-narrow": "uke i md.",
	"field-weekday-narrow": "uked.",
	"field-quarter-narrow": "kv.",
	"field-sun-short-relative+-1": "sist søn.",
	"field-day-relative+-1": "i går",
	"dayPeriods-standAlone-abbr-am": "a.m.",
	"field-day-relative+-2": "i forgårs",
	"field-weekday-short": "ukedag",
	"days-format-abbr": [
		"søn.",
		"man.",
		"tir.",
		"ons.",
		"tor.",
		"fre.",
		"lør."
	],
	"field-sun-relative+0": "søndag",
	"dateFormatItem-MMdd": "d.M.",
	"field-sun-relative+1": "neste søndag",
	"dateFormatItem-Gy": "y G",
	"field-day-short": "dag",
	"field-week-narrow": "u.",
	"field-era": "tidsalder",
	"field-fri-narrow-relative+0": "denne fr.",
	"field-fri-narrow-relative+1": "neste fr.",
	"dayPeriods-standAlone-wide-am": "a.m."
}
//end v1.x content
);
